commit 76e0568697150b41fbf121b04d8296db4dbba25f
Author: Kornel Benko <[email protected]>
Date:   Sun Nov 22 15:10:46 2015 +0100

    Cmake export tests: Added development/mathmacros to the list

diff --git a/development/autotests/revertedTests 
b/development/autotests/revertedTests
index 2438aca..1bb1028 100644
--- a/development/autotests/revertedTests
+++ b/development/autotests/revertedTests
@@ -208,3 +208,7 @@ export/examples/(|fr/)seminar_pdf(2|[45]_systemF)
 #
 # GM: Korean? I don't expect this to work with Xe/Lua and TeXfonts.
 export/examples/ko/splash_(dvi3|pdf[45])_texF
+#
+# Following mathmacros tests fail
+export/mathmacros/testcases_master_child_.*
+export/mathmacros/testcases_speed_(dvi|pdf|pdf[23]|(dvi3|pdf[45])_(texF|systemF))

Reply via email to
diff --git a/development/autotests/ExportTests.cmake 
b/development/autotests/ExportTests.cmake
index ea07d3e..fc20f0d 100644
--- a/development/autotests/ExportTests.cmake
+++ b/development/autotests/ExportTests.cmake
@@ -94,7 +94,7 @@ macro(maketestname testname reverted listreverted listignored 
listnonstandard)
     if (nsfound)
       set(${testname} "NON_STANDARD.${${testname}}")
     else ()
-      string(REGEX MATCH "_(systemF|texF|pdf3|pdf2|pdf|dvi)$" _v 
${${testname}})
+      string(REGEX MATCH "_(systemF|texF|pdf3|pdf2|pdf|dvi|lyx16|xhtml)$" _v 
${${testname}})
       # check if test _may_ be in listreverted
       if (_v)
         findexpr(mfound ${testname} ${listrevertedx})
@@ -165,8 +165,8 @@ macro(handlesuspended TestName reverted testlabel)
   setmarkedtestlabel(${TestName} ${myreverted} ${mylabel})
 endmacro()
 
-# preparing to add e.g. development/mathmacro to the foreach() loop
-foreach(libsubfolderx lib/doc lib/examples lib/templates)
+# preparing to add e.g. development/mathmacros to the foreach() loop
+foreach(libsubfolderx lib/doc lib/examples lib/templates 
development/mathmacros)
   set(testlabel "export")
   if (libsubfolderx MATCHES "lib/doc")
     list(APPEND testlabel "manuals")
@@ -174,14 +174,15 @@ foreach(libsubfolderx lib/doc lib/examples lib/templates)
     list(APPEND testlabel "examples")
   elseif (libsubfolderx MATCHES "lib/templates")
     list(APPEND testlabel "templates")
-  elseif (libsubfolderx MATCHES "development/mathmacro")
+  elseif (libsubfolderx MATCHES "development/mathmacros")
     list(APPEND testlabel "mathmacros")
   elseif (libsubfolderx MATCHES "autotests/.+")
     list(APPEND testlabel "autotests")
   endif()
   set(LIBSUB_SRC_DIR "${TOP_SRC_DIR}/${libsubfolderx}")
   string(REGEX REPLACE "^(lib|development|autotests)/" "" libsubfolder 
"${libsubfolderx}")
-  set(LIBSUB_SRC_DIR "${TOP_SRC_DIR}/lib/${libsubfolder}")
+  set(LIBSUB_SRC_DIR "${TOP_SRC_DIR}/${libsubfolderx}")
+  message(STATUS "Handling export dir ${LIBSUB_SRC_DIR}")
   file(GLOB_RECURSE lyx_files RELATIVE "${LIBSUB_SRC_DIR}" 
"${LIBSUB_SRC_DIR}/*.lyx")
   list(SORT lyx_files)
   # Now create 2 lists. One for files in a language dir, one without